@@ -19,11 +19,11 @@ class HubertWithKmeans(nn.Module):
         self,
         checkpoint_path,
         kmeans_path,
-        target_sample_khz = 50000,
+        target_sample_hz = 50000,
         seq_len_multiple_of = None
     ):
         super().__init__()
-        self.target_sample_khz = target_sample_khz
+        self.target_sample_hz = target_sample_hz
         self.seq_len_multiple_of = seq_len_multiple_of
 
         model_path = Path(checkpoint_path)
@@ -55,12 +55,12 @@ class HubertWithKmeans(nn.Module):
         self,
         wav_input,
         flatten = True,
-        input_sample_khz = None
+        input_sample_hz = None
     ):
         device = wav_input.device
 
-        if exists(input_sample_khz):
-            wav_input = resample(wav_input, input_sample_khz, self.target_sample_khz)
+        if exists(input_sample_hz):
+            wav_input = resample(wav_input, input_sample_hz, self.target_sample_hz)
 
         if exists(self.seq_len_multiple_of):
             wav_input = curtail_to_multiple(wav_input, self.seq_len_multiple_of)
